@@ -866,7 +866,9 @@
                 contentType: "application/json"
             }).then(function () {
 
-                Dashboard.alert('Settings saved.');
+                require(['toast'], function (toast) {
+                    toast('Settings saved.');
+                });
             });
 
         } else {
