@@ -112,7 +112,7 @@
                 $('.btnPlayTrailer', page).addClass('hide');
             }
 
-            if (SyncManager.isAvailable(item, user)) {
+            if (LibraryBrowser.enableSync(item, user)) {
                 $('.btnSync', page).removeClass('hide');
             } else {
                 $('.btnSync', page).addClass('hide');
@@ -1886,9 +1886,9 @@
 
         var id = getParameterByName('id');
 
-        Dashboard.confirm("Are you sure you wish to split the media sources into separate items?", "Split Media Apart", function (confirmResult) {
+        require(['confirm'], function (confirm) {
 
-            if (confirmResult) {
+            confirm("Are you sure you wish to split the media sources into separate items?", "Split Media Apart").then(function () {
 
                 Dashboard.showLoadingMsg();
 
@@ -1902,7 +1902,7 @@
 
                     reload(page);
                 });
-            }
+            });
         });
     }
 
@@ -1951,20 +1951,21 @@
 
     function deleteTimer(page, id) {
 
-        Dashboard.confirm(Globalize.translate('MessageConfirmRecordingCancellation'), Globalize.translate('HeaderConfirmRecordingCancellation'), function (result) {
+        require(['confirm'], function (confirm) {
 
-            if (result) {
+            confirm(Globalize.translate('MessageConfirmRecordingCancellation'), Globalize.translate('HeaderConfirmRecordingCancellation')).then(function () {
 
                 Dashboard.showLoadingMsg();
 
                 ApiClient.cancelLiveTvTimer(id).then(function () {
 
-                    Dashboard.alert(Globalize.translate('MessageRecordingCancelled'));
+                    require(['toast'], function (toast) {
+                        toast(Globalize.translate('MessageRecordingCancelled'));
+                    });
 
                     reload(page);
                 });
-            }
-
+            });
         });
     }
 
@@ -1987,8 +1988,10 @@
 
         $('.btnSync', page).on('click', function () {
 
-            SyncManager.showMenu({
-                items: [currentItem]
+            require(['syncDialog'], function (syncDialog) {
+                syncDialog.showMenu({
+                    items: [currentItem]
+                });
             });
         });
 
