@@ -1,4 +1,4 @@
-﻿(function (window, $) {
+﻿define([], function () {
 
     var currentDialogOptions;
 
@@ -20,7 +20,9 @@
 
         if (!target) {
 
-            Dashboard.alert(Globalize.translate('MessagePleaseSelectDeviceToSyncTo'));
+            require(['toast'], function (toast) {
+                toast(Globalize.translate('MessagePleaseSelectDeviceToSyncTo'));
+            });
             return;
         }
 
@@ -52,8 +54,9 @@
         }).then(function () {
 
             paperDialogHelper.close(dlg);
-            $(window.SyncManager).trigger('jobsubmit');
-            Dashboard.alert(Globalize.translate('MessageSyncJobCreated'));
+            require(['toast'], function (toast) {
+                toast(Globalize.translate('MessageSyncJobCreated'));
+            });
         });
     }
 
@@ -78,7 +81,7 @@
 
         return new Promise(function (resolve, reject) {
 
-            require(['paper-checkbox', 'paper-input', 'jqmcollapsible'], function () {
+            require(['paper-checkbox', 'paper-input', 'emby-collapsible'], function () {
                 renderFormInternal(options);
                 resolve();
             });
@@ -159,8 +162,7 @@
             dialogOptions.Options.indexOf('ItemLimit') != -1) {
 
             html += '<br/>';
-            html += '<div data-role="collapsible" data-mini="true">';
-            html += '<h2>' + Globalize.translate('HeaderAdvanced') + '</h2>';
+            html += '<emby-collapsible title="' + Globalize.translate('HeaderAdvanced') + '">';
             html += '<div style="padding:0 0 1em;">';
             if (dialogOptions.Options.indexOf('SyncNewContent') != -1) {
                 html += '<br/>';
@@ -176,14 +178,14 @@
                 html += '<div class="fieldDescription">' + Globalize.translate('LabelItemLimitHelp') + '</div>';
                 html += '</div>';
             }
-            html += '</div>';
+            html += '</emby-collapsible>';
             html += '</div>';
         }
 
         //html += '</div>';
         //html += '</div>';
 
-        $(elem).html(html).trigger('create');
+        $(elem).html(html);
 
         $('#selectSyncTarget', elem).on('change', function () {
 
@@ -299,6 +301,17 @@
         };
     }
 
+    function setQualityFieldVisible(form, visible) {
+
+        if (visible) {
+            $('.fldQuality', form).show();
+            $('#selectQuality', form).attr('required', 'required');
+        } else {
+            $('.fldQuality', form).hide();
+            $('#selectQuality', form).removeAttr('required');
+        }
+    }
+
     function onProfileChange(form, profileId) {
 
         var options = currentDialogOptions || {};
@@ -337,25 +350,6 @@
         }
     }
 
-    function loadQualityOptions(form, targetId, dialogOptionsFn) {
-
-        dialogOptionsFn(targetId).then(function (options) {
-
-            renderTargetDialogOptions(form, options);
-        });
-    }
-
-    function setQualityFieldVisible(form, visible) {
-
-        if (visible) {
-            $('.fldQuality', form).show();
-            $('#selectQuality', form).attr('required', 'required');
-        } else {
-            $('.fldQuality', form).hide();
-            $('#selectQuality', form).removeAttr('required');
-        }
-    }
-
     function renderTargetDialogOptions(form, options) {
 
         currentDialogOptions = options;
@@ -385,78 +379,18 @@
         }).join('')).trigger('change');
     }
 
-    function isAvailable(item, user) {
+    function loadQualityOptions(form, targetId, dialogOptionsFn) {
 
-        if (AppInfo.isNativeApp && !Dashboard.capabilities().SupportsSync) {
-            return false;
-        }
+        dialogOptionsFn(targetId).then(function (options) {
 
-        if (user && !user.Policy.EnableSync) {
-            return false;
-        }
-
-        return item.SupportsSync;
+            renderTargetDialogOptions(form, options);
+        });
     }
 
-    window.SyncManager = {
+    return {
 
         showMenu: showSyncMenu,
-        isAvailable: isAvailable,
         renderForm: renderForm,
         setJobValues: setJobValues
     };
-
-    function showSyncButtonsPerUser(page) {
-
-        var apiClient = window.ApiClient;
-
-        if (!apiClient || !apiClient.getCurrentUserId()) {
-            return;
-        }
-
-        Dashboard.getCurrentUser().then(function (user) {
-
-            var item = {
-                SupportsSync: true
-            };
-
-            if (isAvailable(item, user)) {
-                $('.categorySyncButton', page).removeClass('hide');
-            } else {
-                $('.categorySyncButton', page).addClass('hide');
-            }
-        });
-    }
-
-    function onCategorySyncButtonClick(page, button) {
-
-        var category = button.getAttribute('data-category');
-        var parentId = LibraryMenu.getTopParentId();
-
-        SyncManager.showMenu({
-            ParentId: parentId,
-            Category: category
-        });
-    }
-
-    $(document).on('pageinit', ".libraryPage", function () {
-
-        var page = this;
-
-        $('.categorySyncButton', page).on('click', function () {
-
-            onCategorySyncButtonClick(page, this);
-        });
-
-    }).on('pageshow', ".libraryPage", function () {
-
-        var page = this;
-
-        if (!Dashboard.isServerlessPage()) {
-            showSyncButtonsPerUser(page);
-        }
-
-    });
-
-
-})(window, jQuery);
\ No newline at end of file
+});
\ No newline at end of file
