@@ -4,9 +4,10 @@
 
         var msg = Globalize.translate('CancelSyncJobConfirmation');
 
-        Dashboard.confirm(msg, Globalize.translate('HeaderCancelSyncJob'), function (result) {
+        require(['confirm'], function (confirm) {
+
+            confirm(msg, Globalize.translate('HeaderCancelSyncJob')).then(function () {
 
-            if (result) {
                 Dashboard.showLoadingMsg();
 
                 ApiClient.ajax({
@@ -18,7 +19,7 @@
 
                     reloadData(page);
                 });
-            }
+            });
         });
     }
 
@@ -287,9 +288,9 @@
             });
         }
 
-        require(['actionsheet'], function () {
+        require(['actionsheet'], function (actionsheet) {
 
-            ActionSheetElement.show({
+            actionsheet.show({
                 items: menuItems,
                 positionTo: elem,
                 callback: function (id) {
