@@ -211,8 +211,8 @@
                 "mouseup": "_controlVMouseUp"
             });
 
-            slider.bind("mousedown", $.proxy(this._sliderVMouseDown, this))
-                .bind("click", false);
+            slider.on("mousedown", $.proxy(this._sliderVMouseDown, this))
+                .on("click", false);
 
             // We have to instantiate a new function object for the unbind to work properly
             // since the method itself is defined in the prototype (causing it to unbind everything)
@@ -235,7 +235,7 @@
                 "keyup": "_handleKeyup"
             });
 
-            this.handle.bind("click", false);
+            this.handle.on("click", false);
 
             //this._handleFormReset();
 
